==> camel-k-model-v1-6.3.0-sources.jar: io/fabric8/camelk/v1/TaskFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TaskFluentImpl<A extends TaskFluent<A>> extends BaseFluent<A> implements TaskFluent<A>{
  public TaskFluentImpl() {
  }
  public TaskFluentImpl(Task instance) {
    this.withBuildah(instance.getBuildah()); 
    this.withBuilder(instance.getBuilder()); 
    this.withKaniko(instance.getKaniko()); 
    this.withS2i(instance.getS2i()); 
    this.withSpectrum(instance.getSpectrum()); 
  }
  private BuildahTaskBuilder buildah;
  private BuilderTaskBuilder builder;
  private KanikoTaskBuilder kaniko;
  private S2iTaskBuilder s2i;
  private SpectrumTaskBuilder spectrum;
  
  /**
   * This method has been deprecated, please use method buildBuildah instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildahTask getBuildah() {
    return this.buildah!=null ?this.buildah.build():null;
  }
  public BuildahTask buildBuildah() {
    return this.buildah!=null ?this.buildah.build():null;
  }
  public A withBuildah(BuildahTask buildah) {
    _visitables.get("buildah").remove(this.buildah);
    if (buildah!=null){ this.buildah= new BuildahTaskBuilder(buildah); _visitables.get("buildah").add(this.buildah);} else { this.buildah = null; _visitables.get("buildah").remove(this.buildah); } return (A) this;
  }
  public Boolean hasBuildah() {
    return this.buildah != null;
  }
  public TaskFluent.BuildahNested<A> withNewBuildah() {
    return new TaskFluentImpl.BuildahNestedImpl();
  }
  public TaskFluent.BuildahNested<A> withNewBuildahLike(BuildahTask item) {
    return new TaskFluentImpl.BuildahNestedImpl(item);
  }
  public TaskFluent.BuildahNested<A> editBuildah() {
    return withNewBuildahLike(getBuildah());
  }
  public TaskFluent.BuildahNested<A> editOrNewBuildah() {
    return withNewBuildahLike(getBuildah() != null ? getBuildah(): new BuildahTaskBuilder().build());
  }
  public TaskFluent.BuildahNested<A> editOrNewBuildahLike(BuildahTask item) {
    return withNewBuildahLike(getBuildah() != null ? getBuildah(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildBuilder instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuilderTask getBuilder() {
    return this.builder!=null ?this.builder.build():null;
  }
  public BuilderTask buildBuilder() {
    return this.builder!=null ?this.builder.build():null;
  }
  public A withBuilder(BuilderTask builder) {
    _visitables.get("builder").remove(this.builder);
    if (builder!=null){ this.builder= new BuilderTaskBuilder(builder); _visitables.get("builder").add(this.builder);} else { this.builder = null; _visitables.get("builder").remove(this.builder); } return (A) this;
  }
  public Boolean hasBuilder() {
    return this.builder != null;
  }
  public TaskFluent.BuilderNested<A> withNewBuilder() {
    return new TaskFluentImpl.BuilderNestedImpl();
  }
  public TaskFluent.BuilderNested<A> withNewBuilderLike(BuilderTask item) {
    return new TaskFluentImpl.BuilderNestedImpl(item);
  }
  public TaskFluent.BuilderNested<A> editBuilder() {
    return withNewBuilderLike(getBuilder());
  }
  public TaskFluent.BuilderNested<A> editOrNewBuilder() {
    return withNewBuilderLike(getBuilder() != null ? getBuilder(): new BuilderTaskBuilder().build());
  }
  public TaskFluent.BuilderNested<A> editOrNewBuilderLike(BuilderTask item) {
    return withNewBuilderLike(getBuilder() != null ? getBuilder(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildKaniko instead.
   * @return The buildable object.
   */
  @Deprecated
  public KanikoTask getKaniko() {
    return this.kaniko!=null ?this.kaniko.build():null;
  }
  public KanikoTask buildKaniko() {
    return this.kaniko!=null ?this.kaniko.build():null;
  }
  public A withKaniko(KanikoTask kaniko) {
    _visitables.get("kaniko").remove(this.kaniko);
    if (kaniko!=null){ this.kaniko= new KanikoTaskBuilder(kaniko); _visitables.get("kaniko").add(this.kaniko);} else { this.kaniko = null; _visitables.get("kaniko").remove(this.kaniko); } return (A) this;
  }
  public Boolean hasKaniko() {
    return this.kaniko != null;
  }
  public TaskFluent.KanikoNested<A> withNewKaniko() {
    return new TaskFluentImpl.KanikoNestedImpl();
  }
  public TaskFluent.KanikoNested<A> withNewKanikoLike(KanikoTask item) {
    return new TaskFluentImpl.KanikoNestedImpl(item);
  }
  public TaskFluent.KanikoNested<A> editKaniko() {
    return withNewKanikoLike(getKaniko());
  }
  public TaskFluent.KanikoNested<A> editOrNewKaniko() {
    return withNewKanikoLike(getKaniko() != null ? getKaniko(): new KanikoTaskBuilder().build());
  }
  public TaskFluent.KanikoNested<A> editOrNewKanikoLike(KanikoTask item) {
    return withNewKanikoLike(getKaniko() != null ? getKaniko(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildS2i instead.
   * @return The buildable object.
   */
  @Deprecated
  public S2iTask getS2i() {
    return this.s2i!=null ?this.s2i.build():null;
  }
  public S2iTask buildS2i() {
    return this.s2i!=null ?this.s2i.build():null;
  }
  public A withS2i(S2iTask s2i) {
    _visitables.get("s2i").remove(this.s2i);
    if (s2i!=null){ this.s2i= new S2iTaskBuilder(s2i); _visitables.get("s2i").add(this.s2i);} else { this.s2i = null; _visitables.get("s2i").remove(this.s2i); } return (A) this;
  }
  public Boolean hasS2i() {
    return this.s2i != null;
  }
  public A withNewS2i(String contextDir,String name,String tag) {
    return (A)withS2i(new S2iTask(contextDir, name, tag));
  }
  public TaskFluent.S2iNested<A> withNewS2i() {
    return new TaskFluentImpl.S2iNestedImpl();
  }
  public TaskFluent.S2iNested<A> withNewS2iLike(S2iTask item) {
    return new TaskFluentImpl.S2iNestedImpl(item);
  }
  public TaskFluent.S2iNested<A> editS2i() {
    return withNewS2iLike(getS2i());
  }
  public TaskFluent.S2iNested<A> editOrNewS2i() {
    return withNewS2iLike(getS2i() != null ? getS2i(): new S2iTaskBuilder().build());
  }
  public TaskFluent.S2iNested<A> editOrNewS2iLike(S2iTask item) {
    return withNewS2iLike(getS2i() != null ? getS2i(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpectrum instead.
   * @return The buildable object.
   */
  @Deprecated
  public SpectrumTask getSpectrum() {
    return this.spectrum!=null ?this.spectrum.build():null;
  }
  public SpectrumTask buildSpectrum() {
    return this.spectrum!=null ?this.spectrum.build():null;
  }
  public A withSpectrum(SpectrumTask spectrum) {
    _visitables.get("spectrum").remove(this.spectrum);
    if (spectrum!=null){ this.spectrum= new SpectrumTaskBuilder(spectrum); _visitables.get("spectrum").add(this.spectrum);} else { this.spectrum = null; _visitables.get("spectrum").remove(this.spectrum); } return (A) this;
  }
  public Boolean hasSpectrum() {
    return this.spectrum != null;
  }
  public TaskFluent.SpectrumNested<A> withNewSpectrum() {
    return new TaskFluentImpl.SpectrumNestedImpl();
  }
  public TaskFluent.SpectrumNested<A> withNewSpectrumLike(SpectrumTask item) {
    return new TaskFluentImpl.SpectrumNestedImpl(item);
  }
  public TaskFluent.SpectrumNested<A> editSpectrum() {
    return withNewSpectrumLike(getSpectrum());
  }
  public TaskFluent.SpectrumNested<A> editOrNewSpectrum() {
    return withNewSpectrumLike(getSpectrum() != null ? getSpectrum(): new SpectrumTaskBuilder().build());
  }
  public TaskFluent.SpectrumNested<A> editOrNewSpectrumLike(SpectrumTask item) {
    return withNewSpectrumLike(getSpectrum() != null ? getSpectrum(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TaskFluentImpl that = (TaskFluentImpl) o;
    if (buildah != null ? !buildah.equals(that.buildah) :that.buildah != null) return false;
    if (builder != null ? !builder.equals(that.builder) :that.builder != null) return false;
    if (kaniko != null ? !kaniko.equals(that.kaniko) :that.kaniko != null) return false;
    if (s2i != null ? !s2i.equals(that.s2i) :that.s2i != null) return false;
    if (spectrum != null ? !spectrum.equals(that.spectrum) :that.spectrum != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(buildah,  builder,  kaniko,  s2i,  spectrum,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (buildah != null) { sb.append("buildah:"); sb.append(buildah + ","); }
    if (builder != null) { sb.append("builder:"); sb.append(builder + ","); }
    if (kaniko != null) { sb.append("kaniko:"); sb.append(kaniko + ","); }
    if (s2i != null) { sb.append("s2i:"); sb.append(s2i + ","); }
    if (spectrum != null) { sb.append("spectrum:"); sb.append(spectrum); }
    sb.append("}");
    return sb.toString();
  }
  class BuildahNestedImpl<N> extends BuildahTaskFluentImpl<TaskFluent.BuildahNested<N>> implements TaskFluent.BuildahNested<N>,Nested<N>{
    BuildahNestedImpl(BuildahTask item) {
      this.builder = new BuildahTaskBuilder(this, item);
    }
    BuildahNestedImpl() {
      this.builder = new BuildahTaskBuilder(this);
    }
    BuildahTaskBuilder builder;
    public N and() {
      return (N) TaskFluentImpl.this.withBuildah(builder.build());
    }
    public N endBuildah() {
      return and();
    }
    
  }
  class BuilderNestedImpl<N> extends BuilderTaskFluentImpl<TaskFluent.BuilderNested<N>> implements TaskFluent.BuilderNested<N>,Nested<N>{
    BuilderNestedImpl(BuilderTask item) {
      this.builder = new BuilderTaskBuilder(this, item);
    }
    BuilderNestedImpl() {
      this.builder = new BuilderTaskBuilder(this);
    }
    BuilderTaskBuilder builder;
    public N and() {
      return (N) TaskFluentImpl.this.withBuilder(builder.build());
    }
    public N endBuilder() {
      return and();
    }
    
  }
  class KanikoNestedImpl<N> extends KanikoTaskFluentImpl<TaskFluent.KanikoNested<N>> implements TaskFluent.KanikoNested<N>,Nested<N>{
    KanikoNestedImpl(KanikoTask item) {
      this.builder = new KanikoTaskBuilder(this, item);
    }
    KanikoNestedImpl() {
      this.builder = new KanikoTaskBuilder(this);
    }
    KanikoTaskBuilder builder;
    public N and() {
      return (N) TaskFluentImpl.this.withKaniko(builder.build());
    }
    public N endKaniko() {
      return and();
    }
    
  }
  class S2iNestedImpl<N> extends S2iTaskFluentImpl<TaskFluent.S2iNested<N>> implements TaskFluent.S2iNested<N>,Nested<N>{
    S2iNestedImpl(S2iTask item) {
      this.builder = new S2iTaskBuilder(this, item);
    }
    S2iNestedImpl() {
      this.builder = new S2iTaskBuilder(this);
    }
    S2iTaskBuilder builder;
    public N and() {
      return (N) TaskFluentImpl.this.withS2i(builder.build());
    }
    public N endS2i() {
      return and();
    }
    
  }
  class SpectrumNestedImpl<N> extends SpectrumTaskFluentImpl<TaskFluent.SpectrumNested<N>> implements TaskFluent.SpectrumNested<N>,Nested<N>{
    SpectrumNestedImpl(SpectrumTask item) {
      this.builder = new SpectrumTaskBuilder(this, item);
    }
    SpectrumNestedImpl() {
      this.builder = new SpectrumTaskBuilder(this);
    }
    SpectrumTaskBuilder builder;
    public N and() {
      return (N) TaskFluentImpl.this.withSpectrum(builder.build());
    }
    public N endSpectrum() {
      return and();
    }
    
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/TaskFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class TaskFluentImpl<A extends TaskFluent<A>> extends BaseFluent<A> implements TaskFluent<A>{
  public TaskFluentImpl() {
  }
  public TaskFluentImpl(Task instance) {
    if (instance != null) {
      this.withBuildah(instance.getBuildah());
      this.withBuilder(instance.getBuilder());
      this.withKaniko(instance.getKaniko());
      this.withS2i(instance.getS2i());
      this.withSpectrum(instance.getSpectrum());
    }
  }
  private BuildahTaskBuilder buildah;
  private BuilderTaskBuilder builder;
  private KanikoTaskBuilder kaniko;
  private S2iTaskBuilder s2i;
  private SpectrumTaskBuilder spectrum;
  
  /**
   * This method has been deprecated, please use method buildBuildah instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuildahTask getBuildah() {
    return this.buildah!=null ?this.buildah.build():null;
  }
  public BuildahTask buildBuildah() {
    return this.buildah!=null ?this.buildah.build():null;
  }
  public A withBuildah(BuildahTask buildah) {
    _visitables.get("buildah").remove(this.buildah);
    if (buildah!=null){ this.buildah= new BuildahTaskBuilder(buildah); _visitables.get("buildah").add(this.buildah);} else { this.buildah = null; _visitables.get("buildah").remove(this.buildah); } return (A) this;
  }
  public Boolean hasBuildah() {
    return this.buildah != null;
  }
  public TaskFluentImpl.BuildahNested<A> withNewBuildah() {
    return new TaskFluentImpl.BuildahNestedImpl();
  }
  public TaskFluentImpl.BuildahNested<A> withNewBuildahLike(BuildahTask item) {
    return new TaskFluentImpl.BuildahNestedImpl(item);
  }
  public TaskFluentImpl.BuildahNested<A> editBuildah() {
    return withNewBuildahLike(getBuildah());
  }
  public TaskFluentImpl.BuildahNested<A> editOrNewBuildah() {
    return withNewBuildahLike(getBuildah() != null ? getBuildah(): new BuildahTaskBuilder().build());
  }
  public TaskFluentImpl.BuildahNested<A> editOrNewBuildahLike(BuildahTask item) {
    return withNewBuildahLike(getBuildah() != null ? getBuildah(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildBuilder instead.
   * @return The buildable object.
   */
  @Deprecated
  public BuilderTask getBuilder() {
    return this.builder!=null ?this.builder.build():null;
  }
  public BuilderTask buildBuilder() {
    return this.builder!=null ?this.builder.build():null;
  }
  public A withBuilder(BuilderTask builder) {
    _visitables.get("builder").remove(this.builder);
    if (builder!=null){ this.builder= new BuilderTaskBuilder(builder); _visitables.get("builder").add(this.builder);} else { this.builder = null; _visitables.get("builder").remove(this.builder); } return (A) this;
  }
  public Boolean hasBuilder() {
    return this.builder != null;
  }
  public TaskFluentImpl.BuilderNested<A> withNewBuilder() {
    return new TaskFluentImpl.BuilderNestedImpl();
  }
  public TaskFluentImpl.BuilderNested<A> withNewBuilderLike(BuilderTask item) {
    return new TaskFluentImpl.BuilderNestedImpl(item);
  }
  public TaskFluentImpl.BuilderNested<A> editBuilder() {
    return withNewBuilderLike(getBuilder());
  }
  public TaskFluentImpl.BuilderNested<A> editOrNewBuilder() {
    return withNewBuilderLike(getBuilder() != null ? getBuilder(): new BuilderTaskBuilder().build());
  }
  public TaskFluentImpl.BuilderNested<A> editOrNewBuilderLike(BuilderTask item) {
    return withNewBuilderLike(getBuilder() != null ? getBuilder(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildKaniko instead.
   * @return The buildable object.
   */
  @Deprecated
  public KanikoTask getKaniko() {
    return this.kaniko!=null ?this.kaniko.build():null;
  }
  public KanikoTask buildKaniko() {
    return this.kaniko!=null ?this.kaniko.build():null;
  }
  public A withKaniko(KanikoTask kaniko) {
    _visitables.get("kaniko").remove(this.kaniko);
    if (kaniko!=null){ this.kaniko= new KanikoTaskBuilder(kaniko); _visitables.get("kaniko").add(this.kaniko);} else { this.kaniko = null; _visitables.get("kaniko").remove(this.kaniko); } return (A) this;
  }
  public Boolean hasKaniko() {
    return this.kaniko != null;
  }
  public TaskFluentImpl.KanikoNested<A> withNewKaniko() {
    return new TaskFluentImpl.KanikoNestedImpl();
  }
  public TaskFluentImpl.KanikoNested<A> withNewKanikoLike(KanikoTask item) {
    return new TaskFluentImpl.KanikoNestedImpl(item);
  }
  public TaskFluentImpl.KanikoNested<A> editKaniko() {
    return withNewKanikoLike(getKaniko());
  }
  public TaskFluentImpl.KanikoNested<A> editOrNewKaniko() {
    return withNewKanikoLike(getKaniko() != null ? getKaniko(): new KanikoTaskBuilder().build());
  }
  public TaskFluentImpl.KanikoNested<A> editOrNewKanikoLike(KanikoTask item) {
    return withNewKanikoLike(getKaniko() != null ? getKaniko(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildS2i instead.
   * @return The buildable object.
   */
  @Deprecated
  public S2iTask getS2i() {
    return this.s2i!=null ?this.s2i.build():null;
  }
  public S2iTask buildS2i() {
    return this.s2i!=null ?this.s2i.build():null;
  }
  public A withS2i(S2iTask s2i) {
    _visitables.get("s2i").remove(this.s2i);
    if (s2i!=null){ this.s2i= new S2iTaskBuilder(s2i); _visitables.get("s2i").add(this.s2i);} else { this.s2i = null; _visitables.get("s2i").remove(this.s2i); } return (A) this;
  }
  public Boolean hasS2i() {
    return this.s2i != null;
  }
  public A withNewS2i(String contextDir,String name,String tag) {
    return (A)withS2i(new S2iTask(contextDir, name, tag));
  }
  public TaskFluentImpl.S2iNested<A> withNewS2i() {
    return new TaskFluentImpl.S2iNestedImpl();
  }
  public TaskFluentImpl.S2iNested<A> withNewS2iLike(S2iTask item) {
    return new TaskFluentImpl.S2iNestedImpl(item);
  }
  public TaskFluentImpl.S2iNested<A> editS2i() {
    return withNewS2iLike(getS2i());
  }
  public TaskFluentImpl.S2iNested<A> editOrNewS2i() {
    return withNewS2iLike(getS2i() != null ? getS2i(): new S2iTaskBuilder().build());
  }
  public TaskFluentImpl.S2iNested<A> editOrNewS2iLike(S2iTask item) {
    return withNewS2iLike(getS2i() != null ? getS2i(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpectrum instead.
   * @return The buildable object.
   */
  @Deprecated
  public SpectrumTask getSpectrum() {
    return this.spectrum!=null ?this.spectrum.build():null;
  }
  public SpectrumTask buildSpectrum() {
    return this.spectrum!=null ?this.spectrum.build():null;
  }
  public A withSpectrum(SpectrumTask spectrum) {
    _visitables.get("spectrum").remove(this.spectrum);
    if (spectrum!=null){ this.spectrum= new SpectrumTaskBuilder(spectrum); _visitables.get("spectrum").add(this.spectrum);} else { this.spectrum = null; _visitables.get("spectrum").remove(this.spectrum); } return (A) this;
  }
  public Boolean hasSpectrum() {
    return this.spectrum != null;
  }
  public TaskFluentImpl.SpectrumNested<A> withNewSpectrum() {
    return new TaskFluentImpl.SpectrumNestedImpl();
  }
  public TaskFluentImpl.SpectrumNested<A> withNewSpectrumLike(SpectrumTask item) {
    return new TaskFluentImpl.SpectrumNestedImpl(item);
  }
  public TaskFluentImpl.SpectrumNested<A> editSpectrum() {
    return withNewSpectrumLike(getSpectrum());
  }
  public TaskFluentImpl.SpectrumNested<A> editOrNewSpectrum() {
    return withNewSpectrumLike(getSpectrum() != null ? getSpectrum(): new SpectrumTaskBuilder().build());
  }
  public TaskFluentImpl.SpectrumNested<A> editOrNewSpectrumLike(SpectrumTask item) {
    return withNewSpectrumLike(getSpectrum() != null ? getSpectrum(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TaskFluentImpl that = (TaskFluentImpl) o;
    if (!java.util.Objects.equals(buildah, that.buildah)) return false;

    if (!java.util.Objects.equals(builder, that.builder)) return false;

    if (!java.util.Objects.equals(kaniko, that.kaniko)) return false;

    if (!java.util.Objects.equals(s2i, that.s2i)) return false;

    if (!java.util.Objects.equals(spectrum, that.spectrum)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(buildah,  builder,  kaniko,  s2i,  spectrum,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (buildah != null) { sb.append("buildah:"); sb.append(buildah + ","); }
    if (builder != null) { sb.append("builder:"); sb.append(builder + ","); }
    if (kaniko != null) { sb.append("kaniko:"); sb.append(kaniko + ","); }
    if (s2i != null) { sb.append("s2i:"); sb.append(s2i + ","); }
    if (spectrum != null) { sb.append("spectrum:"); sb.append(spectrum); }
    sb.append("}");
    return sb.toString();
  }
  class BuildahNestedImpl<N> extends BuildahTaskFluentImpl<TaskFluentImpl.BuildahNested<N>> implements TaskFluentImpl.BuildahNested<N>,Nested<N>{
    BuildahNestedImpl(BuildahTask item) {
      this.builder = new BuildahTaskBuilder(this, item);
    }
    BuildahNestedImpl() {
      this.builder = new BuildahTaskBuilder(this);
    }
    BuildahTaskBuilder builder;
    public N and() {
      return (N) TaskFluentImpl.this.withBuildah(builder.build());
    }
    public N endBuildah() {
      return and();
    }
    
  }
  class BuilderNestedImpl<N> extends BuilderTaskFluentImpl<TaskFluentImpl.BuilderNested<N>> implements TaskFluentImpl.BuilderNested<N>,Nested<N>{
    BuilderNestedImpl(BuilderTask item) {
      this.builder = new BuilderTaskBuilder(this, item);
    }
    BuilderNestedImpl() {
      this.builder = new BuilderTaskBuilder(this);
    }
    BuilderTaskBuilder builder;
    public N and() {
      return (N) TaskFluentImpl.this.withBuilder(builder.build());
    }
    public N endBuilder() {
      return and();
    }
    
  }
  class KanikoNestedImpl<N> extends KanikoTaskFluentImpl<TaskFluentImpl.KanikoNested<N>> implements TaskFluentImpl.KanikoNested<N>,Nested<N>{
    KanikoNestedImpl(KanikoTask item) {
      this.builder = new KanikoTaskBuilder(this, item);
    }
    KanikoNestedImpl() {
      this.builder = new KanikoTaskBuilder(this);
    }
    KanikoTaskBuilder builder;
    public N and() {
      return (N) TaskFluentImpl.this.withKaniko(builder.build());
    }
    public N endKaniko() {
      return and();
    }
    
  }
  class S2iNestedImpl<N> extends S2iTaskFluentImpl<TaskFluentImpl.S2iNested<N>> implements TaskFluentImpl.S2iNested<N>,Nested<N>{
    S2iNestedImpl(S2iTask item) {
      this.builder = new S2iTaskBuilder(this, item);
    }
    S2iNestedImpl() {
      this.builder = new S2iTaskBuilder(this);
    }
    S2iTaskBuilder builder;
    public N and() {
      return (N) TaskFluentImpl.this.withS2i(builder.build());
    }
    public N endS2i() {
      return and();
    }
    
  }
  class SpectrumNestedImpl<N> extends SpectrumTaskFluentImpl<TaskFluentImpl.SpectrumNested<N>> implements TaskFluentImpl.SpectrumNested<N>,Nested<N>{
    SpectrumNestedImpl(SpectrumTask item) {
      this.builder = new SpectrumTaskBuilder(this, item);
    }
    SpectrumNestedImpl() {
      this.builder = new SpectrumTaskBuilder(this);
    }
    SpectrumTaskBuilder builder;
    public N and() {
      return (N) TaskFluentImpl.this.withSpectrum(builder.build());
    }
    public N endSpectrum() {
      return and();
    }
    
  }
  
}
